@@ -35,12 +35,34 @@ def quantize_to_day(date: str):
 
 
 @jaseci_action()
-def date_day_diff(start_date: str, end_date: str):
+def datetime_now():
+    """Get utc date time for now in iso format"""
+    return datetime.utcnow().isoformat()
+
+
+@jaseci_action()
+def date_now():
+    """Get utc date time for now in iso format"""
+    return datetime.utcnow().date().isoformat()
+
+
+@jaseci_action()
+def timestamp_now():
+    """Get utc date time for now in iso format"""
+    return int(datetime.utcnow().timestamp())
+
+
+@jaseci_action()
+def date_day_diff(start_date: str, end_date: str = None):
     # Try to deal with some incompatible date in old nodes
     # Due date has not been saving in isoformat so this doesn't work
     # for example,'2021-03-31T04:00:00.000Z'
     start_date = datetime.fromisoformat(jtu(start_date.split("T")[0]))
-    end_date = datetime.fromisoformat(jtu(end_date.split("T")[0]))
+
+    if end_date is None:
+        end_date = datetime.utcnow()
+    else:
+        end_date = datetime.fromisoformat(jtu(end_date.split("T")[0]))
 
     delta = end_date - start_date
 
