@@ -1,15 +1,15 @@
 """
 Walker api functions as a mixin
 """
-from jaseci.api.interface import interface
-from jaseci.actor.walker import walker
-from jaseci.graph.node import node
-from jaseci.actor.sentinel import sentinel
+from jaseci.api.interface import Interface
+from jaseci.actor.walker import Walker
+from jaseci.graph.node import Node
+from jaseci.actor.sentinel import Sentinel
 from jaseci.utils.utils import b64decode_str
-from jaseci.utils.id_list import id_list
+from jaseci.utils.id_list import IdList
 
 
-class walker_api:
+class WalkerApi:
     """
     Walker APIs
 
@@ -21,12 +21,12 @@ class walker_api:
     """
 
     def __init__(self):
-        self.spawned_walker_ids = id_list(self)
-        self.yielded_walkers_ids = id_list(self)
+        self.spawned_walker_ids = IdList(self)
+        self.yielded_walkers_ids = IdList(self)
 
-    @interface.private_api(cli_args=["code"])
+    @Interface.private_api(cli_args=["code"])
     def walker_register(
-        self, snt: sentinel = None, code: str = "", encoded: bool = False
+        self, snt: Sentinel = None, code: str = "", encoded: bool = False
     ):
         """
         Allows for the specific parsing and registering of individual walkers.
@@ -44,8 +44,8 @@ class walker_api:
         else:
             return ["Walker not created, invalid code!"]
 
-    @interface.private_api(cli_args=["wlk"])
-    def walker_get(self, wlk: walker, mode: str = "default", detailed: bool = False):
+    @Interface.private_api(cli_args=["wlk"])
+    def walker_get(self, wlk: Walker, mode: str = "default", detailed: bool = False):
         """
         Get a walker rendered with specific mode
         Valid modes: {default, code, ir, keys, }
@@ -59,8 +59,8 @@ class walker_api:
         else:
             return wlk.serialize(detailed=detailed)
 
-    @interface.private_api(cli_args=["wlk"])
-    def walker_set(self, wlk: walker, code: str, mode: str = "default"):
+    @Interface.private_api(cli_args=["wlk"])
+    def walker_set(self, wlk: Walker, code: str, mode: str = "default"):
         """
         Set code/ir for a walker
         Valid modes: {code, ir, }
@@ -76,8 +76,8 @@ class walker_api:
         else:
             return [f"{wlk} code issues encountered!"]
 
-    @interface.private_api()
-    def walker_list(self, snt: sentinel = None, detailed: bool = False):
+    @Interface.private_api()
+    def walker_list(self, snt: Sentinel = None, detailed: bool = False):
         """
         List walkers known to sentinel
         """
@@ -86,8 +86,8 @@ class walker_api:
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    @interface.private_api(cli_args=["wlk"])
-    def walker_delete(self, wlk: walker, snt: sentinel = None):
+    @Interface.private_api(cli_args=["wlk"])
+    def walker_delete(self, wlk: Walker, snt: Sentinel = None):
         """
         Permanently delete walker with given id
         """
@@ -100,8 +100,8 @@ class walker_api:
             ret = {"success": False, "response": f"Walker {wlkid} not found!"}
         return ret
 
-    @interface.private_api(cli_args=["name"])
-    def walker_spawn_create(self, name: str, snt: sentinel = None):
+    @Interface.private_api(cli_args=["name"])
+    def walker_spawn_create(self, name: str, snt: Sentinel = None):
         """
         Creates new instance of walker and returns new walker object
         """
@@ -115,7 +115,7 @@ class walker_api:
         else:
             return ["Walker not found!"]
 
-    @interface.private_api()
+    @Interface.private_api()
     def walker_spawn_list(self, detailed: bool = False):
         """
         List walkers spawned by master
@@ -125,7 +125,7 @@ class walker_api:
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    @interface.private_api(cli_args=["name"])
+    @Interface.private_api(cli_args=["name"])
     def walker_spawn_delete(self, name: str):
         """
         Delete instance of walker
@@ -137,7 +137,7 @@ class walker_api:
         else:
             return [f"Walker {name} not found!"]
 
-    @interface.private_api()
+    @Interface.private_api()
     def walker_spawn_clear(self):
         """
         Delete instance of walker
@@ -149,7 +149,7 @@ class walker_api:
         ret["response"] = f"All {count} spawned walkers destroyed."
         return ret
 
-    @interface.private_api()
+    @Interface.private_api()
     def walker_yield_list(self, detailed: bool = False):
         """
         List walkers spawned by master
@@ -159,7 +159,7 @@ class walker_api:
             walks.append(i.serialize(detailed=detailed))
         return walks
 
-    @interface.private_api(cli_args=["name"])
+    @Interface.private_api(cli_args=["name"])
     def walker_yield_delete(self, name: str):
         """
         Delete instance of walker
@@ -173,7 +173,7 @@ class walker_api:
             ret["response"] = f"Walker {name} not found!"
         return ret
 
-    @interface.private_api()
+    @Interface.private_api()
     def walker_yield_clear(self):
         """
         Delete instance of walker
@@ -185,9 +185,9 @@ class walker_api:
         ret["response"] = f"All {count} yielded walkers destroyed."
         return ret
 
-    @interface.private_api(cli_args=["wlk"])
+    @Interface.private_api(cli_args=["wlk"])
     def walker_prime(
-        self, wlk: walker, nd: node = None, ctx: dict = {}, _req_ctx: dict = {}
+        self, wlk: Walker, nd: Node = None, ctx: dict = {}, _req_ctx: dict = {}
     ):
         """
         Assigns walker to a graph node and primes walker for execution
@@ -195,11 +195,11 @@ class walker_api:
         wlk.prime(nd, prime_ctx=ctx, request_ctx=_req_ctx)
         return [f"Walker primed on node {nd.id}"]
 
-    @interface.private_api(cli_args=["wlk"])
+    @Interface.private_api(cli_args=["wlk"])
     def walker_execute(
         self,
-        wlk: walker,
-        prime: node = None,
+        wlk: Walker,
+        prime: Node = None,
         ctx: dict = {},
         _req_ctx: dict = {},
         profiling: bool = False,
@@ -211,14 +211,14 @@ class walker_api:
             start_node=prime, prime_ctx=ctx, request_ctx=_req_ctx, profiling=profiling
         )
 
-    @interface.private_api(cli_args=["name"])
+    @Interface.private_api(cli_args=["name"])
     def walker_run(
         self,
         name: str,
-        nd: node = None,
+        nd: Node = None,
         ctx: dict = {},
         _req_ctx: dict = {},
-        snt: sentinel = None,
+        snt: Sentinel = None,
         profiling: bool = False,
         is_async: bool = False,
     ):
@@ -237,14 +237,14 @@ class walker_api:
         wlk.register_yield_or_destroy(self.yielded_walkers_ids)
         return res
 
-    @interface.private_api(cli_args=["name"], url_args=["name"])
+    @Interface.private_api(cli_args=["name"], url_args=["name"])
     def wapi(
         self,
         name: str,
-        nd: node = None,
+        nd: Node = None,
         ctx: dict = {},
         _req_ctx: dict = {},
-        snt: sentinel = None,
+        snt: Sentinel = None,
         profiling: bool = False,
     ):
         """
@@ -252,12 +252,12 @@ class walker_api:
         """
         return self.walker_run(name, nd, ctx, _req_ctx, snt, profiling)
 
-    @interface.public_api(cli_args=["wlk"])
+    @Interface.public_api(cli_args=["wlk"])
     def walker_summon(
         self,
         key: str,
-        wlk: walker,
-        nd: node,
+        wlk: Walker,
+        nd: Node,
         ctx: dict = {},
         _req_ctx: dict = {},
         global_sync: bool = True,
@@ -279,11 +279,11 @@ class walker_api:
         walk.destroy()
         return res
 
-    @interface.public_api(url_args=["nd", "wlk"], allowed_methods=["post", "get"])
+    @Interface.public_api(url_args=["nd", "wlk"], allowed_methods=["post", "get"])
     def walker_callback(
         self,
-        nd: node,
-        wlk: walker,
+        nd: Node,
+        wlk: Walker,
         key: str,
         ctx: dict = {},
         _req_ctx: dict = {},
