@@ -3,15 +3,15 @@ Mix in for jac code object in Jaseci
 """
 import json
 from jaseci.utils.utils import logger
-from jaseci.jac.ir.ast import ast
+from jaseci.jac.ir.ast import Ast
 import hashlib
 
 
-class jac_json_enc(json.JSONEncoder):
+class JacJsonEnc(json.JSONEncoder):
     """Custom Json encoder for Jac ASTs"""
 
     def default(self, obj):
-        if isinstance(obj, ast):
+        if isinstance(obj, Ast):
             retd = {}
             for i in obj.__dict__.keys():
                 if not i.startswith("_"):
@@ -20,7 +20,7 @@ class jac_json_enc(json.JSONEncoder):
         return super().default(obj)
 
 
-class jac_json_dec(json.JSONDecoder):
+class JacJsonDec(json.JSONDecoder):
     """Custom hook for decoding Jac ASTs"""
 
     def __init__(self, *args, **kwargs):
@@ -29,7 +29,7 @@ class jac_json_dec(json.JSONDecoder):
     def object_hook(self, obj):
 
         if isinstance(obj, dict) and "mod_name" in obj and "kid" in obj:
-            ret = ast(mod_name=obj["mod_name"], fresh_start=False)
+            ret = Ast(mod_name=obj["mod_name"], fresh_start=False)
             for i in obj.keys():
                 setattr(ret, i, obj[i])
             return ret
@@ -38,15 +38,15 @@ class jac_json_dec(json.JSONDecoder):
 
 def jac_ast_to_ir(jac_ast):
     """Convert AST to IR string"""
-    return json.dumps(cls=jac_json_enc, obj=jac_ast)
+    return json.dumps(cls=JacJsonEnc, obj=jac_ast)
 
 
 def jac_ir_to_ast(ir):
     """Convert AST to IR string"""
-    return json.loads(cls=jac_json_dec, s=ir)
+    return json.loads(cls=JacJsonDec, s=ir)
 
 
-class jac_code:
+class JacCode:
     """Obj mixin to code pickling"""
 
     def __init__(self, code_ir=None):
@@ -71,11 +71,11 @@ class jac_code:
         """Apply's IR to object"""
         self.code_ir = ir if (isinstance(ir, str)) else jac_ast_to_ir(ir)
         self.code_sig = hashlib.md5(self.code_ir.encode()).hexdigest()
-        jac_code.refresh(self)  # should disregard overloaded versions
+        JacCode.refresh(self)  # should disregard overloaded versions
 
     def parse_jac(self, code, dir, start_rule="start"):
         """Generate AST tree from Jac code text"""
-        tree = ast(
+        tree = Ast(
             jac_text=code, start_rule=start_rule, mod_name=self.name, mod_dir=dir
         )
         self.errors = tree._parse_errors
