@@ -1,22 +1,21 @@
-import sys
 import io
-from jaseci.svcs.meta_svc import meta_svc
-
-from jaseci.actor.sentinel import sentinel
-from jaseci.graph.graph import graph
-import jaseci.jac.tests.dot_code as dtc
-
+import sys
 from unittest import TestCase
+
+import jaseci.jac.tests.dot_code as dtc
+from jaseci.actor.sentinel import Sentinel
+from jaseci.graph.graph import Graph
+from jaseci.svc import MetaService
 from jaseci.utils.utils import TestCaseHelper
 
 
-class test_dot(TestCaseHelper, TestCase):
+class TestDot(TestCaseHelper, TestCase):
     """Unit test for DOT support"""
 
     def setUp(self):
         super().setUp()
-        self.gph = graph(m_id="anon", h=meta_svc().hook())
-        self.sent = sentinel(m_id=self.gph._m_id, h=self.gph._h)
+        self.gph = Graph(m_id="anon", h=MetaService().hook())
+        self.sent = Sentinel(m_id=self.gph._m_id, h=self.gph._h)
         self.old_stdout = sys.stdout
         self.new_stdout = io.StringIO()
         sys.stdout = self.new_stdout
