@@ -1,17 +1,18 @@
-from unittest import TestCase
-from jaseci.svcs.meta_svc import meta_svc
-from jaseci.utils.utils import TestCaseHelper
 import os
+from unittest import TestCase
+
+from jaseci.svc import MetaService
+from jaseci.utils.utils import TestCaseHelper
 
 
-class core_test(TestCaseHelper, TestCase):
+class CoreTest(TestCaseHelper, TestCase):
     """Unit tests for Jac Core APIs"""
 
     fixture_src = __file__
 
     def setUp(self):
         super().setUp()
-        self.meta = meta_svc()
+        self.meta = MetaService()
         self.smast = self.meta.super_master()
         self.mast = self.meta.master(h=self.smast._h)
 
